CKEDITOR.appendTo — CKEditor Sample

# CKEditor Samples » Append To Page Element Using JavaScript Code

`CKEDITOR.appendTo` is basically to place editors inside existing DOM elements. Unlike `CKEDITOR.replace`, a target container to be replaced is no longer necessary. A new editor instance is inserted directly wherever it is desired.

    CKEDITOR.appendTo( 'container_id',
    	{ /* Configuration options to be used. */ }
    	'Editor content to be used.'
    );